XBImageEditorOperaClip class

Inheritance

Constructors

XBImageEditorOperaClip({required XBImageEditorClipMaskChangeInfo clipInfo, required Point<double> referenceTL, required Size referenceSize})

Properties

clipInfo XBImageEditorClipMaskChangeInfo
final
hashCode int
The hash code for this object.
no setterinherited
newSize Size
no setter
newTL Point<double>
no setter
referenceSize Size
参考的尺寸
final
referenceTL Point<double>
参考的起始点
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tlbr List<Point<double>>
左上和右下的坐标 这个坐标,是以图片的原始尺寸为坐标系 直接表示在原始图片的位置,不需要再计算
no setter
xRDScale double
no setter
yRDScale double
no setter

Methods

deepCopy() XBImageEditorOpera
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited