XBImageEditorOperaMosaic class

Inheritance

Constructors

XBImageEditorOperaMosaic({required List<XBImageEditorOperaMosaicPoint> points, required double lineWidth, required double scale})

Properties

hashCode int
The hash code for this object.
no setterinherited
lineWidth double
final
points List<XBImageEditorOperaMosaicPoint>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scale double
final

Methods

deepCopy() XBImageEditorOpera
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited