XBImageEditorOperaRotate class
- Inheritance
-
- Object
- XBImageEditorOpera
- XBImageEditorOperaRotate
Constructors
- XBImageEditorOperaRotate({required XBImageEditorOperaRotateEnum rotate})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- rotate → XBImageEditorOperaRotateEnum
-
旋转了多少度
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
deepCopy(
) → XBImageEditorOpera -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited